﻿using NPOI.HPSF;
using NPOI.HSSF.UserModel;
using NPOI.HSSF.Util;
using NPOI.SS.Formula.Eval;
using NPOI.SS.UserModel;
using NPOI.SS.Util;
using NPOI.XSSF.UserModel;
using NPOI.XWPF.UserModel;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Web;

namespace Mall.Common.Plugin
{
    /// <summary>
    /// npoi帮助类
    /// </summary>
    public class NPOIHelper
    {

        #region 从excel中将数据导出到datatable

        /// <summary>
        /// 读取excel
        /// </summary>
        /// <param name="strFileName">excel文件路径</param>
        /// <param name="SheetIndex">需要导出的sheet序号</param>
        /// <param name="HeaderRowIndex">列头所在行号，-1表示没有列头</param>
        /// <param name="needHeader">列头</param>
        /// <returns></returns>
        public static DataTable ImportExceltoDt(String strFileName, int SheetIndex, int HeaderRowIndex, bool needHeader)
        {
            IWorkbook wb;
            using (FileStream file = new FileStream(strFileName, FileMode.Open, FileAccess.Read))
            {
                wb = WorkbookFactory.Create(file);
            }
            ISheet sheet = wb.GetSheetAt(SheetIndex);
            DataTable table = ImportDt(sheet, HeaderRowIndex, needHeader);
            return table;
        }

        /// <summary>
        /// 将制定sheet中的数据导出到datatable中
        /// </summary>
        /// <param name="sheet">需要导出的sheet</param>
        /// <param name="HeaderRowIndex">列头所在行号，-1表示没有列头</param>
        /// <param name="needHeader">是否导出表头</param>
        /// <returns></returns>
        static DataTable ImportDt(ISheet sheet, int HeaderRowIndex, bool needHeader)
        {
            DataTable table = new DataTable();
            IRow headerRow;
            int cellCount;
            try
            {
                if (HeaderRowIndex < 0 || !needHeader)
                {
                    headerRow = sheet.GetRow(0);
                    cellCount = headerRow.LastCellNum;

                    for (int i = headerRow.FirstCellNum; i <= cellCount; i++)
                    {
                        DataColumn column = new DataColumn(Convert.ToString(i));
                        table.Columns.Add(column);
                    }
                }
                else
                {
                    headerRow = sheet.GetRow(HeaderRowIndex);
                    cellCount = headerRow.LastCellNum;

                    for (int i = headerRow.FirstCellNum; i <= cellCount; i++)
                    {
                        if (headerRow.GetCell(i) == null)
                        {
                            if (table.Columns.IndexOf(Convert.ToString(i)) > 0)
                            {
                                DataColumn column = new DataColumn(Convert.ToString("重复列名" + i));
                                table.Columns.Add(column);
                            }
                            else
                            {
                                DataColumn column = new DataColumn(Convert.ToString(i));
                                table.Columns.Add(column);
                            }

                        }
                        else if (table.Columns.IndexOf(headerRow.GetCell(i).ToString()) > 0)
                        {
                            DataColumn column = new DataColumn(Convert.ToString("重复列名" + i));
                            table.Columns.Add(column);
                        }
                        else
                        {
                            DataColumn column = new DataColumn(headerRow.GetCell(i).ToString());
                            table.Columns.Add(column);
                        }
                    }
                }
                int rowCount = sheet.LastRowNum;
                for (int i = (HeaderRowIndex + 1); i <= sheet.LastRowNum; i++)
                {
                    try
                    {
                        IRow row;
                        if (sheet.GetRow(i) == null)
                        {
                            row = sheet.CreateRow(i);
                        }
                        else
                        {
                            row = sheet.GetRow(i);
                        }

                        DataRow dataRow = table.NewRow();

                        for (int j = row.FirstCellNum; j <= cellCount; j++)
                        {
                            try
                            {
                                if (row.GetCell(j) != null)
                                {
                                    switch (row.GetCell(j).CellType)
                                    {
                                        case CellType.String:
                                            String str = row.GetCell(j).StringCellValue;
                                            if (str != null && str.Length > 0)
                                            {
                                                dataRow[j] = str.ToString();
                                            }
                                            else
                                            {
                                                dataRow[j] = null;
                                            }
                                            break;
                                        case CellType.Numeric:
                                            if (DateUtil.IsCellDateFormatted(row.GetCell(j)))
                                            {
                                                dataRow[j] = DateTime.FromOADate(row.GetCell(j).NumericCellValue);
                                            }
                                            else
                                            {
                                                dataRow[j] = Convert.ToDouble(row.GetCell(j).NumericCellValue);
                                            }
                                            break;
                                        case CellType.Boolean:
                                            dataRow[j] = Convert.ToString(row.GetCell(j).BooleanCellValue);
                                            break;
                                        case CellType.Error:
                                            dataRow[j] = ErrorEval.GetText(row.GetCell(j).ErrorCellValue);
                                            break;
                                        case CellType.Formula:
                                            switch (row.GetCell(j).CachedFormulaResultType)
                                            {
                                                case CellType.String:
                                                    String strFORMULA = row.GetCell(j).StringCellValue;
                                                    if (strFORMULA != null && strFORMULA.Length > 0)
                                                    {
                                                        dataRow[j] = strFORMULA.ToString();
                                                    }
                                                    else
                                                    {
                                                        dataRow[j] = null;
                                                    }
                                                    break;
                                                case CellType.Numeric:
                                                    dataRow[j] = Convert.ToString(row.GetCell(j).NumericCellValue);
                                                    break;
                                                case CellType.Boolean:
                                                    dataRow[j] = Convert.ToString(row.GetCell(j).BooleanCellValue);
                                                    break;
                                                case CellType.Error:
                                                    dataRow[j] = ErrorEval.GetText(row.GetCell(j).ErrorCellValue);
                                                    break;
                                                default:
                                                    dataRow[j] = "";
                                                    break;
                                            }
                                            break;
                                        default:
                                            dataRow[j] = "";
                                            break;
                                    }
                                }
                            }
                            catch (Exception exception)
                            {
                                LogHelper.Write(exception, "ImportDt_1");
                            }
                        }
                        table.Rows.Add(dataRow);
                    }
                    catch (Exception exception)
                    {
                        LogHelper.Write(exception, "ImportDt_2");
                    }
                }
            }
            catch (Exception exception)
            {
                LogHelper.Write(exception, "ImportDt_3");
            }
            return table;
        }

        #endregion

        /// <summary>
        /// 判断是否为数字
        /// </summary>
        /// <param name="message"></param>
        /// <param name="result"></param>
        /// <returns></returns>
        public static bool IsNumeric(String message, out double result)
        {
            Regex rex = new Regex(@"^[-]?\d+[.]?\d*$");
            result = -1;
            if (rex.IsMatch(message))
            {
                result = double.Parse(message);
                return true;
            }
            else
                return false;

        }

        /// <summary>
        /// excel 指定行插入数据
        /// </summary>
        /// <param name="dtSource"></param>
        /// <param name="SheetName"></param>
        /// <param name="Path"></param>
        /// <param name="NewPath"></param>
        /// <param name="rowIndex"></param>
        /// <param name="FontName"></param>
        /// <param name="FontHeight"></param>
        /// <param name="height"></param>
        public static void ExportInsert(DataTable dtSource, string SheetName, string Path, string NewPath, int rowIndex = 0, string FontName = "宋体", double FontHeight = 0, short height = 0)
        {
            FileStream file = new FileStream(Path, FileMode.Open, FileAccess.Read);
            XSSFWorkbook workbook = new XSSFWorkbook(file);
            XSSFSheet sheet = workbook.GetSheet(SheetName) as XSSFSheet;

            foreach (DataRow row in dtSource.Rows)
            {
                #region 填充内容

                XSSFRow dataRow = sheet.CreateRow(rowIndex) as XSSFRow;
                if (height > 0)
                {
                    dataRow.Height = height;
                }
                foreach (DataColumn column in dtSource.Columns)
                {
                    XSSFCell newCell = dataRow.CreateCell(column.Ordinal) as XSSFCell;
                    ICellStyle style = workbook.CreateCellStyle();
                    style.WrapText = true;//自动换行
                    IFont font = workbook.CreateFont();
                    font.FontName = FontName;
                    if (FontHeight > 0)
                    {
                        font.FontHeight = FontHeight;
                    }
                    style.SetFont(font);
                    style.Alignment = HorizontalAlignment.Center;
                    newCell.CellStyle = style;
                    String drValue = row[column].ToString();

                    newCell.SetCellValue(drValue);
                }

                #endregion

                rowIndex++;
            }
            FileStream out1 = new FileStream(NewPath, FileMode.Create);
            workbook.Write(out1);
            workbook.Close();
            out1.Close();
        }

        /// <summary>
        /// 测试插入数据  月度考勤专用
        /// </summary>
        /// <param name="dtSource"></param>
        /// <param name="SheetName"></param>
        /// <param name="Path"></param>
        /// <param name="NewPath"></param>
        /// <param name="rowIndex"></param>
        /// <param name="FontName"></param>
        /// <param name="FontHeight"></param>
        /// <param name="height"></param>
        public static void ExportInsertAndMergeCells(DataTable dtSource, string SheetName, string Path, string NewPath, int rowIndex = 0, string FontName = "宋体", double FontHeight = 0, short height = 0)
        {
            FileStream file = new FileStream(Path, FileMode.Open, FileAccess.Read);
            XSSFWorkbook workbook = new XSSFWorkbook(file);
            XSSFSheet sheet = workbook.GetSheet(SheetName) as XSSFSheet;
            string OldDepStr = "";
            int startNum = rowIndex;
            int EndNum = dtSource.Rows.Count + rowIndex;
            foreach (DataRow row in dtSource.Rows)
            {
                #region 填充内容

                XSSFRow dataRow = sheet.CreateRow(rowIndex) as XSSFRow;
                if (height > 0)
                {
                    dataRow.Height = height;
                }
                foreach (DataColumn column in dtSource.Columns)
                {
                    XSSFCell newCell = dataRow.CreateCell(column.Ordinal) as XSSFCell;
                    ICellStyle style = workbook.CreateCellStyle();
                    style.WrapText = true;//自动换行
                    IFont font = workbook.CreateFont();
                    font.FontName = FontName;
                    if (FontHeight > 0)
                    {
                        font.FontHeight = FontHeight;
                    }
                    style.SetFont(font);
                    style.Alignment = HorizontalAlignment.Center;
                    style.VerticalAlignment = NPOI.SS.UserModel.VerticalAlignment.Center;
                    newCell.CellStyle = style;
                    String drValue = row[column].ToString();

                    newCell.SetCellValue(drValue);
                }

                #endregion
                //合并单元格
                if (row["部门"].ToString() != OldDepStr)
                {
                    OldDepStr = row["部门"].ToString();
                    if (OldDepStr == "")
                    {
                        var region = new CellRangeAddress(startNum, rowIndex - 1, 2, 2);
                        sheet.AddMergedRegion(region);
                        startNum = rowIndex;
                    }
                    else
                    {
                        if (startNum != rowIndex)
                        {
                            if (OldDepStr != "")
                            {
                                var region = new CellRangeAddress(startNum, rowIndex - 1, 2, 2);
                                sheet.AddMergedRegion(region);
                            }
                            else
                            {
                                startNum = rowIndex + 1;
                            }
                            startNum = rowIndex;
                        }
                    }
                }
                else
                {
                    if (OldDepStr == "")
                    {
                        startNum = rowIndex + 1;
                    }
                }
                rowIndex++;
                if (EndNum == rowIndex && startNum != rowIndex)
                {//最后一条数据
                    var region = new CellRangeAddress(startNum, rowIndex - 1, 2, 2);
                    sheet.AddMergedRegion(region);
                }
            }
            FileStream out1 = new FileStream(NewPath, FileMode.Create);
            workbook.Write(out1);
            workbook.Close();
            out1.Close();
        }
    }
}